bayespy.inference.vmp.transformations.RotateGaussianMarkovChain.setup
=====================================================================

.. currentmodule:: bayespy.inference.vmp.transformations

.. automethod:: RotateGaussianMarkovChain.setup